;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "eldoc-box" "20250920.125"
  "Display documentation in childframe."
  '((emacs "27.1"))
  :url "https://github.com/casouri/eldoc-box"
  :commit "fead2cef661790417267e5498d4d14806e020f99"
  :revdesc "fead2cef6617"
  :authors '(("Yuan Fu" . "casouri@gmail.com"))
  :maintainers '(("Yuan Fu" . "casouri@gmail.com")))
